@@ -411,6 +411,7 @@ account_dnd_recv(GtkWidget *widget, GdkDragContext *dc, gint x, gint y,
 static void
 update_editable(PurpleConnection *gc, AccountPrefsDialog *dialog)
 {
+	GtkStyle *style;
 	gboolean set;
 	GList *l;
 
@@ -422,10 +423,21 @@ update_editable(PurpleConnection *gc, AccountPrefsDialog *dialog)
 
 	set = !(purple_account_is_connected(dialog->account) || purple_account_is_connecting(dialog->account));
 	gtk_widget_set_sensitive(dialog->protocol_menu, set);
-	gtk_widget_set_sensitive(dialog->username_entry, set);
+	gtk_editable_set_editable(GTK_EDITABLE(dialog->username_entry), set);
+	style = set ? NULL : gtk_widget_get_style(dialog->username_entry);
+	gtk_widget_modify_base(dialog->username_entry, GTK_STATE_NORMAL,
+			style ? &style->base[GTK_STATE_INSENSITIVE] : NULL);
 
-	for (l = dialog->user_split_entries ; l != NULL ; l = l->next)
-		gtk_widget_set_sensitive((GtkWidget *)l->data, set);
+	for (l = dialog->user_split_entries ; l != NULL ; l = l->next) {
+		if (GTK_IS_EDITABLE(l->data)) {
+			gtk_editable_set_editable(GTK_EDITABLE(l->data), set);
+			style = set ? NULL : gtk_widget_get_style(GTK_WIDGET(l->data));
+			gtk_widget_modify_base(GTK_WIDGET(l->data), GTK_STATE_NORMAL,
+					style ? &style->base[GTK_STATE_INSENSITIVE] : NULL);
+		} else {
+			gtk_widget_set_sensitive(GTK_WIDGET(l->data), set);
+		}
+	}
 }
 
 static void
@@ -817,7 +829,8 @@ add_protocol_options(AccountPrefsDialog *dialog)
 	dialog->protocol_frame = vbox = gtk_vbox_new(FALSE, PIDGIN_HIG_BOX_SPACE);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), PIDGIN_HIG_BORDER);
 #ifdef USE_HILDON
-	gtk_notebook_insert_page(GTK_NOTEBOOK(dialog->notebook), _pidgin_make_container_scrollable(vbox, -1, 220),
+	gtk_notebook_insert_page(GTK_NOTEBOOK(dialog->notebook),
+			_pidgin_make_container_scrollable(vbox),
 			gtk_label_new_with_mnemonic(_("Ad_vanced")), 1);
 #else /* !USE_HILDON */
 	gtk_notebook_insert_page(GTK_NOTEBOOK(dialog->notebook), vbox,
@@ -1555,14 +1568,19 @@ pidgin_account_dialog_show(PidginAccountDialogType type,
 	main_vbox = pidgin_dialog_get_vbox_with_properties(GTK_DIALOG(win), FALSE, PIDGIN_HIG_BOX_SPACE);
 
 	dialog->notebook = notebook = gtk_notebook_new();
+#ifdef USE_HILDON
+	gtk_box_pack_start(GTK_BOX(main_vbox), notebook, TRUE, TRUE, 0);
+#else /* !USE_HILDON */
 	gtk_box_pack_start(GTK_BOX(main_vbox), notebook, FALSE, FALSE, 0);
+#endif /* USE_HILDON */
 	gtk_widget_show(GTK_WIDGET(notebook));
 
 	/* Setup the inner vbox */
 	dialog->top_vbox = vbox = gtk_vbox_new(FALSE, PIDGIN_HIG_BORDER);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox), PIDGIN_HIG_BORDER);
 #ifdef USE_HILDON
-	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), _pidgin_make_container_scrollable(vbox, -1, 220),
+	gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
+			_pidgin_make_container_scrollable(vbox),
 			gtk_label_new_with_mnemonic(_("_Basic")));
 #else /* !USE_HILDON */
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox,
@@ -1592,7 +1610,8 @@ pidgin_account_dialog_show(PidginAccountDialogType type,
 	dbox = gtk_vbox_new(FALSE, PIDGIN_HIG_BORDER);
 	gtk_container_set_border_width(GTK_CONTAINER(dbox), PIDGIN_HIG_BORDER);
 #ifdef USE_HILDON
-	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), _pidgin_make_container_scrollable(dbox, -1, 220),
+	gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
+			_pidgin_make_container_scrollable(dbox),
 			gtk_label_new_with_mnemonic(_("P_roxy")));
 #else /* !USE_HILDON */
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), dbox,
@@ -1601,8 +1620,10 @@ pidgin_account_dialog_show(PidginAccountDialogType type,
 	gtk_widget_show(dbox);
 	add_proxy_options(dialog, dbox);
 
+#ifdef USE_CLOSE_AND_CANCEL_BUTTONS 
 	/* Cancel button */
 	pidgin_dialog_add_button(GTK_DIALOG(win), GTK_STOCK_CANCEL, G_CALLBACK(cancel_account_prefs_cb), dialog);
+#endif /* USE_CLOSE_AND_CANCEL_BUTTONS  */
 
 	/* Save button */
 	button = pidgin_dialog_add_button(GTK_DIALOG(win),
@@ -1944,7 +1965,13 @@ close_accounts_cb(GtkWidget *w, AccountsWindow *dialog)
 	pidgin_accounts_window_hide();
 }
 
-
+#define ACCOUNTS_LIST_HAS_ENABLED
+#ifdef USE_HILDON
+#	if HILDON_CHECK_VERSION(2,1,0)
+#		undef ACCOUNTS_LIST_HAS_ENABLED
+#	endif /* HILDON < 2.1.0 */
+#endif /* USE_HILDON */
+#ifdef ACCOUNTS_LIST_HAS_ENABLED
 static void
 enabled_cb(GtkCellRendererToggle *renderer, gchar *path_str,
 			   gpointer data)
@@ -1974,6 +2001,7 @@ enabled_cb(GtkCellRendererToggle *renderer, gchar *path_str,
 
 	purple_account_set_enabled(account, PIDGIN_UI, !enabled);
 }
+#endif /* ACCOUNTS_LIST_HAS_ENABLED */
 
 static void
 add_columns(GtkWidget *treeview, AccountsWindow *dialog)
@@ -1981,6 +2009,7 @@ add_columns(GtkWidget *treeview, AccountsWindow *dialog)
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 
+#ifdef ACCOUNTS_LIST_HAS_ENABLED
 	/* Enabled */
 	renderer = gtk_cell_renderer_toggle_new();
 
@@ -1992,6 +2021,7 @@ add_columns(GtkWidget *treeview, AccountsWindow *dialog)
 
 	gtk_tree_view_column_set_resizable(column, FALSE);
 	gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), column);
+#endif /* ACCOUNTS_LIST_HAS_ENABLED */
 
 	/* Username column */
 	column = gtk_tree_view_column_new();
@@ -2197,7 +2227,6 @@ static GtkWidget *
 create_accounts_list(AccountsWindow *dialog)
 {
 	GtkWidget *frame;
-	GtkWidget *sw;
 	GtkWidget *label;
 	GtkWidget *treeview;
 	GtkTreeSelection *sel;
@@ -2237,16 +2266,6 @@ create_accounts_list(AccountsWindow *dialog)
 	gtk_misc_set_alignment(GTK_MISC(label), 0.5, 0.5);
 	gtk_notebook_append_page(GTK_NOTEBOOK(accounts_window->notebook), label, NULL);
 
-	/* Create the scrolled window. */
-	sw = gtk_scrolled_window_new(0, 0);
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw),
-					GTK_POLICY_AUTOMATIC,
-					GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(sw),
-					GTK_SHADOW_NONE);
-	gtk_notebook_append_page(GTK_NOTEBOOK(accounts_window->notebook), sw, NULL);
-	gtk_widget_show(sw);
-
 	/* Create the list model. */
 	dialog->model = gtk_list_store_new(NUM_COLUMNS,
 					GDK_TYPE_PIXBUF,   /* COLUMN_ICON */
@@ -2262,6 +2281,10 @@ create_accounts_list(AccountsWindow *dialog)
 #ifdef USE_HILDON
 	if (g_object_class_find_property(g_type_class_peek(GTK_TYPE_TREE_VIEW), "allow-checkbox-mode"))
 		g_object_set(G_OBJECT(treeview), "allow-checkbox-mode", FALSE, NULL);
+#if HILDON_CHECK_VERSION(2,1,0)
+	if (g_object_class_find_property(g_type_class_peek(GTK_TYPE_TREE_VIEW), "hildon-ui-mode"))
+		g_object_set(G_OBJECT(treeview), "hildon-ui-mode", HILDON_UI_MODE_EDIT, NULL);
+#endif /* HILDON > 2.1.0 */
 #endif /* USE_HILDON */
 	dialog->treeview = treeview;
 	gtk_tree_view_set_rules_hint(GTK_TREE_VIEW(treeview), TRUE);
@@ -2276,7 +2299,9 @@ create_accounts_list(AccountsWindow *dialog)
 	g_signal_connect(G_OBJECT(treeview), "button_press_event",
 					 G_CALLBACK(account_treeview_double_click_cb), dialog);
 
-	gtk_container_add(GTK_CONTAINER(sw), treeview);
+	gtk_notebook_append_page(GTK_NOTEBOOK(accounts_window->notebook),
+		pidgin_make_scrollable(treeview, GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC, GTK_SHADOW_NONE, -1, -1), 
+		NULL);
 
 	add_columns(treeview, dialog);
 	gtk_tree_view_columns_autosize(GTK_TREE_VIEW(treeview));
@@ -2371,8 +2396,10 @@ pidgin_accounts_window_show(void)
 	dialog->delete_button = button;
 	gtk_widget_set_sensitive(button, FALSE);
 
+#ifdef USE_CLOSE_AND_CANCEL_BUTTONS
 	/* Close button */
 	pidgin_dialog_add_button(GTK_DIALOG(win), GTK_STOCK_CLOSE, G_CALLBACK(close_accounts_cb), dialog);
+#endif /* USE_CLOSE_AND_CANCEL_BUTTONS */
 
 	purple_signal_connect(pidgin_account_get_handle(), "account-modified",
 	                    accounts_window,
